#!/bin/ksh
#-------------------------------------------------------------------------
# Celerra<F2>_SNMP_report.ksh
#
#  Rev : 1.0
#  <C> TS brund 2008
#
#-------------------------------------------------------------------------

#-------------------------------------------------------------------------
# Rev : 1.0 (09/2008)
#
#---------------------------------------------------------------------------

VERSION=1.0
#-----------------------------------------------------------------#
# CONSTANT PART
#-----------------------------------------------------------------#
NAS_DB=/nas
export NAS_DB

#-----------------------------------------------------------------#
# FS config File :  
# FS_CONFIG_FILE=$SNMP_HOME/CELERRA_SNMP_FS_CONFIG.${HOSTNAME}
# example : ( list of filesystem to monitor )
#
# 1#MountPoint_fs1
# 2#MountPoint_fs2
# 3#MountPoint_fs3
# 4#....
# 5#....
#----------------------------
# Directory SNMP
# 
#     FS ( directory )
#	CAPA (file)
#	line1	capafs1
#	line2	capafs2
#	line3	capafs3
#	...
#
#	SIZE (file)
#	line1	sizefs1
#	line2	sizefs2
#	line3	sizefs3
#	...
#
#	NAME (file)
#	line1	sizefs1
#	line2	sizefs2
#	line3	sizefs3
#	...
#
#     SYS
#	INFO (file)
#	line1	CPU used
#	line2	MEMORY free
#	line3 	THREADS RUNNABLE
#	line4	THREADS BLOCKED
#	
#    CIFS
#	INFO (file)
#	line1	TotalAllSmb
#	line2	TotalSmb
#	line3 	TotalTrans2Smb
#	line4	TotalTransNTSmb
#	line5	unsupported
#
#     NFS
#	INFO (file)
#	line1	v2 read
#	line2	v2 write
#	line3	v3 read
#	line4	v3 write
#	line5	v4 read
#	line6	v4 write
#	line7 	ncalls
#
#----------------------------

SNMP_HOME=/outils/system/snmp
TMP_FILE1=/tmp/celerra_snmp.tmp1
TMP_FILE2=/tmp/celerra_snmp.tmp2
HOSTNAME=`hostname`

FS_CONFIG_FILE=$SNMP_HOME/CELERRA_SNMP_FS_CONFIG.${HOSTNAME}

if [ ! -d $SNMP_HOME/FS ]; then mkdir $SNMP_HOME/FS; fi
if [ ! -d $SNMP_HOME/SYS ]; then mkdir $SNMP_HOME/SYS; fi
if [ ! -d $SNMP_HOME/CIFS ]; then mkdir $SNMP_HOME/CIFS; fi
if [ ! -d $SNMP_HOME/NFS ]; then mkdir $SNMP_HOME/NFS; fi
if [ ! -d $SNMP_HOME/FSIDX ]; then mkdir $SNMP_HOME/FSIDX; fi

make_fs_report()
{
	awk -F'#' '{print $1}' $FS_CONFIG_FILE > $SNMP_HOME/FSIDX/1
	/bin/rm $SNMP_HOME/FS/NAME
	/bin/rm $SNMP_HOME/FS/SIZE
	/bin/rm $SNMP_HOME/FS/CAPA

	for INFO_FS in `cat $FS_CONFIG_FILE`
	do
		ID=`echo $INFO_FS | awk -F'#' '{print $1}'`
		FSNAME=`echo $INFO_FS | awk -F'#' '{print $2}'`
		INFO=`/nas/bin/server_df server_2 /$FSNAME | tail -1`
                echo $FSNAME >> $SNMP_HOME/FS/NAME
                case "$INFO" in
                failed*)echo 0 >> $SNMP_HOME/FS/SIZE
                        echo 0 >> $SNMP_HOME/FS/CAPA;;
                *)
                echo "$INFO" | awk '{print $(NF-4)}' >> $SNMP_HOME/FS/SIZE
                echo "$INFO" | awk '{print $(NF-1)}' | sed "s/%//" >> $SNMP_HOME/FS/CAPA;;
                esac
	done
}

make_sys_report()
{
	/nas/bin/server_sysstat server_2 > $TMP_FILE1
	grep cpu $TMP_FILE1 | awk -F'= ' '{print (100-$2)}' > $SNMP_HOME/SYS/INFO
	grep memory $TMP_FILE1 | awk -F'= ' '{print $2}' | sed "s/ //g" >> $SNMP_HOME/SYS/INFO
	grep "threads runnable" $TMP_FILE1 | awk -F'= ' '{print $2}' >> $SNMP_HOME/SYS/INFO
	grep "threads blocked" $TMP_FILE1 | awk -F'= ' '{print $2}' >> $SNMP_HOME/SYS/INFO
}

make_cifs_report()
{
	/nas/bin/server_cifsstat server_2 | tail -1 > $TMP_FILE1
	awk '{print $1}' $TMP_FILE1 > $SNMP_HOME/CIFS/INFO
	awk '{print $2}' $TMP_FILE1 >> $SNMP_HOME/CIFS/INFO
	awk '{print $3}' $TMP_FILE1 >> $SNMP_HOME/CIFS/INFO
	awk '{print $4}' $TMP_FILE1 >> $SNMP_HOME/CIFS/INFO
	awk '{print $5}' $TMP_FILE1 >> $SNMP_HOME/CIFS/INFO
}

make_nfs_report()
{
	/nas/bin/server_nfsstat server_2 > $TMP_FILE1
	grep "^read " $TMP_FILE1 | awk '{print $2}' > $SNMP_HOME/NFS/INFO
	grep "^write " $TMP_FILE1 | awk '{print $2}' >> $SNMP_HOME/NFS/INFO
	grep "^v3read " $TMP_FILE1 | awk '{print $2}' >> $SNMP_HOME/NFS/INFO
	grep "^v3read " $TMP_FILE1 | awk '{print $2}' >> $SNMP_HOME/NFS/INFO
	grep "^v4read " $TMP_FILE1 | awk '{print $2}' >> $SNMP_HOME/NFS/INFO
	grep "^v4read " $TMP_FILE1 | awk '{print $2}' >> $SNMP_HOME/NFS/INFO
	tail -1 $TMP_FILE1 | awk '{print $1}' >> $SNMP_HOME/NFS/INFO
}

make_fs_report
make_sys_report
make_cifs_report
make_nfs_report

